/*
 * Copyright (c) 2019 Yellicode
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
/**
 * Performs a sequence of model transforms, where the output of each transform is
 * the input of the next transform.
 */
var ModelTransformPipeline = /** @class */ (function () {
    /**
     * Creates a new ModelTransformPipeline, optionally initialized with a collection of transforms.
     * @param transform sAny transforms to initialize the pipeline with.
     */
    function ModelTransformPipeline() {
        var transforms = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            transforms[_i] = arguments[_i];
        }
        this.transforms = transforms || [];
    }
    /**
    * Adds a new collection of transforms to the pipeline.
    * @param transforms The transforms to be added.
    */
    ModelTransformPipeline.prototype.addRange = function () {
        var _this = this;
        var transforms = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            transforms[_i] = arguments[_i];
        }
        transforms.forEach(function (t) {
            _this.transforms.push(t);
        });
    };
    /**
     * Adds a new transform to the pipeline.
     * @param transform The transform to be added.
     */
    ModelTransformPipeline.prototype.add = function (transform) {
        if (!transform)
            return;
        this.transforms.push(transform);
    };
    /**
    * Transforms the source model by applying the specified transforms in sequence.
    * @returns The output of the last transform that was applied.
    */
    ModelTransformPipeline.prototype.transform = function (model) {
        if (this.transforms == null)
            return model;
        var transformedModel = model;
        this.transforms.forEach(function (t) {
            transformedModel = t.transform(transformedModel);
        });
        return transformedModel;
    };
    return ModelTransformPipeline;
}());
export { ModelTransformPipeline };
